@@ -3,13 +3,11 @@ use warnings;
 
 package HTML::Widgets::NavMenu;
 
-our $VERSION = '1.0302';
+our $VERSION = '1.0500';
 
 package HTML::Widgets::NavMenu::Error;
 
-use Error qw(:try);
-
-use base "Error";
+use base "HTML::Widgets::NavMenu::Object";
 
 package HTML::Widgets::NavMenu::Error::Redirect;
 
@@ -21,9 +19,9 @@ sub CGIpm_perform_redirect
 {
     my $self = shift;
 
-    my $q = shift;
+    my $cgi = shift;
 
-    print $q->redirect($q->script_name() . $self->{-redirect_path});
+    print $cgi->redirect($cgi->script_name() . $self->{-redirect_path});
     exit;
 }
 
@@ -33,8 +31,8 @@ use strict;
 
 use base qw(HTML::Widgets::NavMenu::Object);
 
-__PACKAGE__->mk_accessors(
-    qw(host host_url title label direct_url url_type)
+__PACKAGE__->mk_acc_ref([
+    qw(host host_url title label direct_url url_type)]
     );
 
 sub _init
@@ -43,7 +41,7 @@ sub _init
 
     while (my ($k, $v) = each(%$args))
     {
-        $self->set($k,$v);
+        $self->$k($v);
     }
     
     return 0;
@@ -61,13 +59,13 @@ package HTML::Widgets::NavMenu::Iterator::GetCurrentlyActive;
 
 use base 'HTML::Widgets::NavMenu::Iterator::Base';
 
-__PACKAGE__->mk_accessors(qw(
+__PACKAGE__->mk_acc_ref([qw(
     _item_found
     _leading_path_coords
     _ret_coords
     _temp_coords
     _tree
-    ));
+    )]);
 
 sub _init
 {
@@ -174,14 +172,13 @@ package HTML::Widgets::NavMenu;
 use base 'HTML::Widgets::NavMenu::Object';
 
 use HTML::Widgets::NavMenu::Url;
-use Error qw(:try);
 
 require HTML::Widgets::NavMenu::Iterator::NavMenu;
 require HTML::Widgets::NavMenu::Iterator::SiteMap;
 require HTML::Widgets::NavMenu::Tree::Node;
 require HTML::Widgets::NavMenu::Predicate;
 
-__PACKAGE__->mk_accessors(qw(
+__PACKAGE__->mk_acc_ref([qw(
     _current_coords
     current_host
     _hosts
@@ -191,7 +188,7 @@ __PACKAGE__->mk_accessors(qw(
     _traversed_tree
     _tree_contents
     _ul_classes
-    ));
+    )]);
 
 sub _init
 {
@@ -269,8 +266,12 @@ sub _register_path_info
 
     if (defined($redir_path))
     {
-        throw HTML::Widgets::NavMenu::Error::Redirect
-            -redirect_path => ($redir_path."/");
+        my $error = HTML::Widgets::NavMenu::Error::Redirect->new();
+
+        $error->{'-redirect_path'} = ($redir_path."/");
+        $error->{'msg'} = "Need to redirect";
+
+        die $error;
     }
 
     $path_info =~ s!^\/!!;
@@ -1027,7 +1028,7 @@ below under "The Node Description Component Class".
 =item 'nav_links_obj'
 
 This points to a hash reference whose keys are link IDs for
-the Firefox "Site Navigatoin Toolbar" 
+the Firefox "Site Navigation Toolbar" 
 ( L<http://www.bolwin.com/software/snb.shtml> ) and compatible programs,
 and its values are Node Description objects. (see "The Node Description 
 Class" below). Here's a sample code that renders the links as 
